clear;

% Find a unitary U
[U,X]=qr(randn(100));

% Find a unitary V
[V,X]=qr(randn(100));

% Form a diagonal matrix with exponentially decaying entries
S=diag((2).^(-1:-1:-100));

% Create a matrix A that is full rank, but with a large range of singular
% values
A=U*S*V;

% Show it's full rank numerically...
rank(A)

% QR using classical gram-schmidt
[Q1,R1]=clgs(A);

% QR using modified gram-schmidt
[Q2,R2]=gs_m(A);

% QR using Matlab standard
[Q3,R3]=qr(A);

% Plot the diagonal of R
semilogy(1:100,abs(diag(R1)),'x',1:100,abs(diag(R2)),'o',1:100,abs(diag(R3)),'--')
ylabel('Diagonal of R, r_{j,j}')
xlabel('Index j')
legend('Classical GS','Modified GS','Matlab QR')
title('Diagonal of R')

figure;
imagesc(abs(Q1'*Q1));
colorbar;
title('Classical GS, Q^*Q')

% Orthogonality of Classical GS
max(max(abs(Q1'*Q1-eye(100))))

figure;
imagesc(abs(Q2'*Q2));
colorbar;
title('Modified GS, Q^*Q')

% Orthogonality of Modified GS
max(max(abs(Q2'*Q2-eye(100))))

figure;
imagesc(abs(Q3'*Q3));
colorbar;
title('Matlab GS, Q^*Q')

% Orthoginality of the Matlab Standard
max(max(abs(Q3'*Q3-eye(100))))
